@@ -1,8 +1,8 @@
 # Copyright (C) 2003-2023 Namcap contributors, see AUTHORS for details.
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from Namcap.tests.pkgbuild_test import PkgbuildTest
 import Namcap.rules.makepkgfunctions as module
+from Namcap.tests.pkgbuild_test import PkgbuildTest
 
 
 class NamcapMakepkgfunctionsTest(PkgbuildTest):
@@ -43,5 +43,5 @@ package() {
         bad_calls = ["msg", "msg2", "warning", "error", "plain"]
         r = self.run_on_pkg(self.pkgbuild1)
         self.assertEqual(r.errors, [])
-        self.assertEqual(set(r.warnings), set(("makepkg-function-used %s", i) for i in bad_calls))
+        self.assertEqual(set(r.warnings), set(("makepkg-function-used %s", (i,)) for i in bad_calls))
         self.assertEqual(r.infos, [])
